/**
 * The sentiment of the input.
 */
export declare type Sentiment = {
    score: number;
    vote: string;
};
/**
 * The main detected intent (the one with the highest score). Use the `classifications` function to obtain a list by rank.
 */
export declare type Intent = {
    intent: string;
    score: number;
    domain: string;
};
/**
 * A detected language.
 */
export declare type DetectedLanguage = {
    alpha3: string;
    alpha2: string;
    language: string;
    score: number;
};
/**
 * A classification of the input as a match to intent.
 */
export declare type IntentClassification = {
    intent: string;
    score: number;
};
export declare class NlpjsEngine {
    private readonly _manager;
    private constructor();
    static build(settings: any, modelPath: string): Promise<NlpjsEngine>;
    private recognize;
    classifications(input: string): Promise<[IntentClassification] | undefined>;
    static detectLanguage(input: string, languages: [], limit?: Number): [DetectedLanguage];
    entities(input: string): Promise<[any]>;
    sentiment(input: string): Promise<Sentiment | undefined>;
    intent(input: string): Promise<Intent | undefined>;
    answer(input: string): Promise<string | undefined>;
    slots(input: string): Promise<any>;
}
