"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NlpjsEngine = void 0;
const node_nlp_1 = require("node-nlp");
class NlpjsEngine {
    constructor(nlu) {
        this._manager = nlu;
    }
    static build(settings, modelPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const nlu = new node_nlp_1.NlpManager(settings);
            yield nlu.load(modelPath);
            return new NlpjsEngine(nlu);
        });
    }
    recognize(text) {
        return __awaiter(this, void 0, void 0, function* () {
            return this._manager.process(text);
        });
    }
    classifications(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            if (result) {
                return Promise.resolve(result.classifications.reduce((acc, classification) => {
                    if (classification.value > 0) {
                        acc.push({ intent: classification.label, score: classification.value });
                    }
                    return acc;
                }, []));
            }
            return Promise.resolve(undefined);
        });
    }
    static detectLanguage(input, languages, limit = 3) {
        const language = new node_nlp_1.Language();
        const result = language.guess(input, languages, limit);
        if (result) {
            return result;
        }
    }
    entities(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            if (result) {
                return Promise.resolve(result.entities);
            }
            return Promise.resolve(undefined);
        });
    }
    sentiment(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            if (result) {
                return Promise.resolve(result.sentiment);
            }
            return Promise.resolve(undefined);
        });
    }
    intent(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            if (result) {
                return Promise.resolve({ intent: result.intent, score: result.score, domain: result.domain });
            }
            return Promise.resolve(undefined);
        });
    }
    answer(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            if (result) {
                return Promise.resolve(result.answer);
            }
            return Promise.resolve(undefined);
        });
    }
    slots(input) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.recognize(input);
            const context = {};
            result.entities.forEach(entity => {
                context[entity.entity] = entity;
            });
            return context;
        });
    }
}
exports.NlpjsEngine = NlpjsEngine;
//# sourceMappingURL=engine.js.map